@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -375,7 +375,7 @@ valgrind_init_src_preview (VgDefaultView *view, GtkTreeStore *model, GtkTreeIter
 	VgToolView *tool = (VgToolView *) view;
 	GtkTreeIter iter;
 	
-	if (!tool->symtab && !tool->srcdir)
+	if (!tool->srcdir)
 		return;
 	
 	gtk_tree_store_append (model, &iter, root);
@@ -419,24 +419,27 @@ view_show_error (VgDefaultView *view, GtkTreeStore *model, VgError *err)
 			gtk_tree_store_append (model, &iter, &root);
 			
 			str = g_string_new (stack->where == VG_WHERE_AT ? "at " : "by ");
-			g_string_append (str, stack->symbol ? stack->symbol : "??");
-			g_string_append (str, " [");
+			g_string_append (str, stack->symbol ? stack->symbol : "???");
 			
-			if (stack->type == VG_STACK_SOURCE) {
-				if (stack->info.src.filename) {
-					g_string_append (str, stack->info.src.filename);
-					if (stack->info.src.lineno) {
-						g_string_append_printf (str, ":%u", stack->info.src.lineno);
-						load = TRUE;
+			if (stack->type != VG_STACK_EMPTY) {
+				g_string_append (str, " [");
+			
+				if (stack->type == VG_STACK_SOURCE) {
+					if (stack->info.src.filename) {
+						g_string_append (str, stack->info.src.filename);
+						if (stack->info.src.lineno) {
+							g_string_append_printf (str, ":%u", stack->info.src.lineno);
+							load = TRUE;
+						}
 					}
+				} else {
+					g_string_append (str, "in ");
+					g_string_append (str, stack->info.object);
 				}
-			} else {
-				g_string_append (str, "in ");
-				g_string_append (str, stack->info.object);
+				
+				g_string_append_c (str, ']');
 			}
 			
-			g_string_append_c (str, ']');
-			
 			gtk_tree_store_set (model, &iter,
 					    COL_STRING_DISPLAY, str->str,
 					    COL_POINTER_ERROR, err,
@@ -865,17 +868,10 @@ read_src_lines (const char *filename, size_t first, size_t last, size_t target)
 	return buf;
 }
 
-static int
-str_ends_with (const char *str, const char *match)
-{
-	return !(strcmp (str + strlen (str) - strlen (match), match));
-}
-
 static char *
 resolve_full_path (VgToolView *tool, VgErrorStack *stack)
 {
 	const char *filename;
-	SymTabSymbol *sym;
 	char *path;
 	
 	if (!(filename = stack->info.src.filename))
@@ -884,20 +880,6 @@ resolve_full_path (VgToolView *tool, VgErrorStack *stack)
 	if (*filename == '/')
 		return g_strdup (filename);
 	
-	if (tool->symtab && (sym = symtab_resolve_addr (tool->symtab, (void *) stack->addr, FALSE))) {
-		if (sym->filename != NULL) {
-			if (*sym->filename == '/' && str_ends_with (sym->filename, filename)) {
-				path = g_strdup (sym->filename);
-				symtab_symbol_free (sym);
-				return path;
-			} else {
-				w(g_warning ("symtab_resolve_addr() found the wrong symbol for 0x%.8x", stack->addr));
-			}
-		}
-		
-		symtab_symbol_free (sym);
-	}
-	
 	if (tool->srcdir) {
 		unsigned int buflen;
 		const char *dir;
