@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -242,7 +242,7 @@ vg_error_stack_new (VgErrorParser *parser, pid_t pid)
 	stack->summary = n->summ_cur;
 	stack->where = VG_WHERE_AT;
 	stack->addr = VG_STACK_ADDR_UNKNOWN;
-	stack->type = VG_STACK_SOURCE;
+	stack->type = VG_STACK_EMPTY;
 	stack->symbol = NULL;
 	stack->info.src.filename = NULL;
 	stack->info.src.lineno = 0;
@@ -612,13 +612,12 @@ vg_error_parser_step (VgErrorParser *parser)
 					if (*start == ' ')
 						start++;
 					
-					if (strncmp (start, "??? ", 4) == 0) {
+					if (!strncmp (start, "???", 3) && (start[3] == ' ' || start[3] == '\0')) {
 						stack->symbol = NULL;
 						start += 3;
 					} else if (*start == '(') {
 						/* not a c/c++ program, hence no symbol */
 						stack->symbol = NULL;
-						start--;
 					} else {
 						/* symbol name */
 						end = start;
@@ -786,6 +785,7 @@ vg_error_stack_to_string (VgErrorStack *stack, GString *str)
 {
 	timestamp_t *stamp = &stack->summary->parent->stamp;
 	pid_t pid = stack->summary->parent->pid;
+	int in;
 	
 	g_string_append (str, "==");
 	vg_error_timestamp_to_string (stamp, str);
@@ -798,14 +798,19 @@ vg_error_stack_to_string (VgErrorStack *stack, GString *str)
 	
 	g_string_append (str, stack->symbol ? stack->symbol : "???");
 	
-	if (stack->type == VG_STACK_SOURCE) {
+	switch (stack->type) {
+	case VG_STACK_EMPTY:
+		/* Stack generated by the Mono JIT (or similar)? */
+		g_string_append_c (str, '\n');
+		break;
+	case VG_STACK_SOURCE:
 		g_string_append_printf (str, " (%s:%u)\n", stack->info.src.filename, stack->info.src.lineno);
-	} else {
-		int in;
-		
+		break;
+	case VG_STACK_OBJECT:
 		in = !strcmp (stack->info.object + strlen (stack->info.object) - 3, ".so");
 		in = in || strstr (stack->info.object, ".so.") != NULL;
 		g_string_append_printf (str, " (%s %s)\n", in ? "in" : "within", stack->info.object);
+		break;
 	}
 }
 
