@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,8 +41,10 @@ typedef struct _VgHelgrindPrefsClass VgHelgrindPrefsClass;
 struct _VgHelgrindPrefs {
 	VgToolPrefs parent_object;
 	
-	GtkToggleButton *private_stacks;
-	GtkOptionMenu *show_last_access;
+	GtkOptionMenu *happens_before;
+	GtkToggleButton *enable_trace_addr;
+	GtkEntry *trace_addr;
+	GtkOptionMenu *trace_level;
 };
 
 struct _VgHelgrindPrefsClass {
