@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,8 +23,6 @@
 
 #include <gtk/gtk.h>
 
-#include "symtab.h"
-
 #ifdef __cplusplus
 extern "C" {
 #pragma }
@@ -46,8 +44,6 @@ struct _VgToolView {
 	const char **argv;    /* argv of program to debug */
 	const char **srcdir;  /* list of src dirs to check for src files */
 	
-	SymTab *symtab;
-	
 	GtkWidget *rules;
 };
 
@@ -79,7 +75,6 @@ GType vg_tool_view_get_type (void);
 
 void vg_tool_view_set_argv (VgToolView *view, const char **argv);
 void vg_tool_view_set_srcdir (VgToolView *view, const char **srcdir);
-void vg_tool_view_set_symtab (VgToolView *view, SymTab *symtab);
 
 void vg_tool_view_clear (VgToolView *view);
 void vg_tool_view_reset (VgToolView *view);
